#ifndef NT2_INCLUDE_FUNCTIONS_LOG1P_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_LOG1P_HPP_INCLUDED

#include <nt2/exponential/include/functions/log1p.hpp>

#endif
